@@ -82,7 +82,7 @@ def recursive_build_pipeline_from_cfg(  cfg,
             parallel_name = "parallel"
             parallel_index +=1
             default_parallel_label = "parallelTransformer"
-            parallel_node_name = f"{parallel_name} #{parallel_index}"
+            parallel_node_name = f"{parallel_name}_no.{parallel_index}"
             
 
             transformers_list = []
@@ -126,7 +126,7 @@ def recursive_build_pipeline_from_cfg(  cfg,
                     nodename2transformer[transformer.node_name] = transformer
                     # update steps list
                     previous_node, _latest_node = update_node(latest_node, transformer.node_name)
-                    parallel_node_pairs[f"process #{str(i)}"]=(previous_node, _latest_node)
+                    parallel_node_pairs[f"process_no.{str(i)}"]=(previous_node, _latest_node)
                     node_name_set.add(_latest_node)
                     parallel_latest_node.append(_latest_node)
 
@@ -141,7 +141,7 @@ def recursive_build_pipeline_from_cfg(  cfg,
                                                                                                                                                             nodename2transformer,
                                                                                                                                                             print_task_result)
                     transformers_list.append(transformer)
-                    parallel_node_pairs[f"process #{str(i)}"]=_node_pairs
+                    parallel_node_pairs[f"process_no.{str(i)}"]=_node_pairs
                     parallel_latest_node.append(_latest_node)
 
 
@@ -473,7 +473,7 @@ def recursive_build_node_from_steps(steps, node_name_set, node_pairs, latest_nod
 
             parallel_name = "parallel"
             parallel_index +=1
-            parallel_node_name = f"{parallel_name} #{parallel_index}"
+            parallel_node_name = f"{parallel_name}_no.{parallel_index}"
 
             transformers_list = []
             parallel_latest_node = []
@@ -524,7 +524,7 @@ def recursive_build_node_from_steps(steps, node_name_set, node_pairs, latest_nod
                     nodename2transformer[sub_transformer.node_name] = sub_transformer
                     # update steps list
                     previous_node, _latest_node = update_node(latest_node, sub_transformer.node_name)
-                    parallel_node_pairs[f"process #{str(i)}"] = (previous_node, _latest_node)
+                    parallel_node_pairs[f"process_no.{str(i)}"] = (previous_node, _latest_node)
                     node_name_set.add(_latest_node)
                     parallel_latest_node.append(_latest_node)
 
